Pedigrees (families and crosses)
================================

.. automodule:: anhima.ped
.. autofunction:: diploid_inheritance
.. autofunction:: diploid_mendelian_error
.. autofunction:: count_diploid_mendelian_error
.. autofunction:: impute_inheritance_nearest
.. autofunction:: tabulate_inheritance_switches
.. autofunction:: tabulate_inheritance_blocks
.. autofunction:: inheritance_block_masks
